searchData={"items":[{"type":"module","title":"Jop","doc":"Logs in memory, spatially and temporally, key value events.\n\nThese events, generated by multiple processes, are then flushed to disk for analysis (e.g. to detect locks).","ref":"Jop.html"},{"type":"module","title":"Usage - Jop","doc":"```\n  iex> \"myjop\"\n  ...> |> Jop.init()\n  ...> |> Jop.log(\"key_1\", :any_term_112)\n  ...> |> Jop.log(\"key_2\", :any_term_133)\n  ...> |> Jop.flush()\nlog stored in jop_myjop.2020_05_12_21.42.49_dates.gz\nlog stored in jop_myjop.2020_05_12_21.42.49_keys.gz\n#Jop \n```","ref":"Jop.html#module-usage"},{"type":"module","title":"Basic example - Jop","doc":"```\n# prepare for logging and return a handle\nmyjop = Jop.init(\"myjop\")\n\n# log with handle event \"key_1\", :any_term_112\nJop.log myjop, \"key_1\", :any_term_112\nProcess.sleep 12\n\n# clear logs\nJop.clear myjop\n\nJop.log myjop, \"key_2\", :any_term_113\nProcess.sleep 12\n\nJop.log myjop, \"key_1\", :any_term_112\nProcess.sleep 12\n\nJop.log myjop, \"key_2\", :any_term_113\n# flush to disk and erase the log\nJop.flush myjop\n\nlog stored in jop_myjop.2020_05_12_21.42.49_dates.gz\nlog stored in jop_myjop.2020_05_12_21.42.49_keys.gz\n#Jop \n```\nwill generate both a temporal (by date) and a spatial (by key) log files:","ref":"Jop.html#module-basic-example"},{"type":"module","title":"Examining the temporal log file - Jop","doc":"```\n# list all operations by date\nzcat jop_myjop.2020_05_12_21.42.49_dates.gz\n\n00:00:00_000.482 \"key_2\": :any_term_113\n00:00:00_014.674 \"key_1\": :any_term_112\n00:00:00_028.568 \"key_2\": :any_term_113\n\n```","ref":"Jop.html#module-examining-the-temporal-log-file"},{"type":"module","title":"Examining the spatial (by key) log file - Jop","doc":"```\n# list all operations by key :\nzcat jop_myjop.2020_05_12_21.42.49_keys.gz\n\n\"key_1\": 00:00:00_014.674 :any_term_112\n\"key_2\": 00:00:00_000.482 :any_term_113\n\"key_2\": 00:00:00_028.568 :any_term_113\n```","ref":"Jop.html#module-examining-the-spatial-by-key-log-file"},{"type":"module","title":"Real life: concurrent process logging - Jop","doc":"Processes log in myjop as follow:\n```\n# Handle can be saved in process state\nmyjop = Jop.ref(\"myjop\")\n\n# Log if logging is activated\nJop.log myjop, \"key_1\", :any_term_112\n```\nConsole activate / deactivate the logging:\n```\n# Activate the logging\n# Starts the logging\nmyjop = Jop.init(\"myjop\")\n\n# Do some queries while the logging is on\ninspect myjop # see how many records\nEnum.count mylog\nEnum.member? mylog, \"mykey\"\n ...\n\n# Flush the logs on disk, keep on logging\nJop.flush myjop, :nostop\n\n# Clear the logs, keep on logging\nJop.clear myjop  # clear all entries and continue logging\n\n# Flush the logs on disk and deactivate the logging\nJop.flush myjop\n\n# Start logging again\nJop.init(\"myjop\")\n```","ref":"Jop.html#module-real-life-concurrent-process-logging"},{"type":"function","title":"Jop.clear/1","doc":"erase all entries from the `jop` handle","ref":"Jop.html#clear/1"},{"type":"function","title":"Jop.flush/2","doc":"write a joplog on disk from a handle.\n2 logs are generated : dates.gz and keys.gz\nunless option :notstop is used, logging is stopped.","ref":"Jop.html#flush/2"},{"type":"function","title":"Jop.init/1","doc":"Initialize Jop with a `log name`.\nreturns a handle `%Joplog{}`","ref":"Jop.html#init/1"},{"type":"function","title":"Jop.initialized?/1","doc":"returns true if the handle  is initialized with an ets table","ref":"Jop.html#initialized?/1"},{"type":"function","title":"Jop.log/3","doc":"log a `key` and its `value` with a `jop` handle \nreturns the handle.","ref":"Jop.html#log/3"},{"type":"function","title":"Jop.ref/1","doc":"returns a handle from a `log_name`","ref":"Jop.html#ref/1"},{"type":"type","title":"Jop.t/0","doc":"","ref":"Jop.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}